Changelog
=========

0.2.2
-----

- Fix pycparser version to prevent bug in pycparser 2.15

0.2.2
-----

- Change naming conventions: secret namespaces, groups and keys

0.2.0
-----

- Don't use the local keychain if the s3keyring config file says so

0.1.0
-----

- Doc fixes
- New keyring method to list secrets associated to a service

0.0.12
------

- Docs fixes
- Fixes in the handling of project-specific configs

0.0.2
-----

- Minor fixes in docs and package data

0.0.1
-----

- Initial release (germangh)
